#!/usr/bin/env python
#****************************************************************
# File: ./archiwe/wsgi/webify.py
# (c) 2010, http://hakmatak.org, MIT License, ALL RIGHTS RESERVED
#****************************************************************

from hakmatak.w10n import W10n
from hakmatak.wsgi.webify import Handler

from archiwe.constant import APP_NAME,APP_VERSION
from archiwe.store import ReaderClassFactory

# wsgi entry point
def application(environ, start_response):
    w10n = W10n()
    w10n.application = "%s/%s-%s" % (w10n.application,APP_NAME,APP_VERSION)
    handler = Handler(
        storeReaderClassFactory=ReaderClassFactory(),
        w10n=w10n
        )
    return handler.do(environ, start_response)

# cgi entry point
if __name__ == '__main__':
    import wsgiref.handlers
    wsgiref.handlers.CGIHandler().run(application)



from distutils.core import setup

setup(
    name = "archiwe",
    version = "0.9.0",
    author = "http://hakmatak.org/dev",
    author_email = "dev@hakmatak.org",
    url = "http://pypi.python.org/pypi/archiwe",
    description = "Webification of archive files",
    long_description = "Archiwe webifies files in archive formats such as zip, tar, etc. It is based on hakmatak, the w10n enabler.",
    classifiers = [
        "Programming Language :: Python",
        #"Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Intended Audience :: End Users/Desktop",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Internet :: WWW/HTTP :: WSGI",
        "Topic :: Software Development :: Libraries :: Python Modules"
    ],
    packages = [
        "archiwe",
        #"archiwe/cli",
        "archiwe/store",
        "archiwe/store/write",
        "archiwe/store/read",
        #"archiwe/wsgi",
    ],
    #requires = ["ctypes","wsgiref.handlers"],
    scripts = [
        "archiwe/cli/archiweread",
        "archiwe/cli/archiwewrite",
    ],
)
